@@ -1,20 +1,22 @@
 import sqlalchemy as sa
 from .builders import ImproperlyConfigured
-from .manager import translation_manager, TranslationManager
-from .translatable import Translatable
+from .manager import translation_manager, TranslationManager, translation_base
+from .translatable import Translatable, UnknownLocaleError
 from .utils import default_locale
 
 
 __all__ = (
     default_locale,
+    translation_base,
     ImproperlyConfigured,
     Translatable,
     TranslationManager,
-    translation_manager
+    translation_manager,
+    UnknownLocaleError
 )
 
 
-__version__ = '0.7.1'
+__version__ = '0.8.0'
 
 
 def make_translatable(
@@ -26,7 +28,7 @@ def make_translatable(
     manager.options.update(options)
 
     sa.event.listen(
-        mapper, 'instrument_class', manager.instrument_translatable_classes
+        mapper, 'instrument_class', manager.instrument_translation_classes
     )
     sa.event.listen(
         mapper, 'after_configured', manager.configure_translatable_classes
