@@ -2,6 +2,12 @@ from inspect import isclass
 import sqlalchemy as sa
 
 
+def option(obj_or_class, option):
+    class_ = obj_or_class if isclass(obj_or_class) else obj_or_class.__class__
+    manager = class_.__translatable__['manager']
+    return manager.option(class_, option)
+
+
 def default_locale(obj):
     class_ = obj.__class__
     manager = class_.__translatable__['manager']
@@ -11,17 +17,6 @@ def default_locale(obj):
     return locale
 
 
-def leaf_classes(classes):
-    for cls in classes:
-        found = False
-        for other_cls in classes:
-            if issubclass(other_cls, cls) and other_cls is not cls:
-                found = True
-                break
-        if not found:
-            yield cls
-
-
 def parent_classes(cls):
     """
     Simple recursive function for listing the parent classes of given class.
@@ -34,12 +29,9 @@ def parent_classes(cls):
 
 
 def all_translated_columns(model):
-    columns = set()
-    for cls in parent_classes(model) + [model]:
-        if hasattr(cls, '__translated_columns__'):
-            for column in cls.__translated_columns__:
-                columns.add(column)
-    return columns
+    for column in sa.inspect(model.__translatable__['class']).columns:
+        if not column.primary_key:
+            yield column
 
 
 def is_string(type_):
